@@ -26,7 +26,7 @@ class Table(object):
             self.df.name = name
 
 
-    names = ['AME2003', 'AME2012', 'DUZU', 'FRDM95', 'KTUY05', 'ETFSI12', 'HFB14']
+    names = ['AME2003', 'AME2003all', 'AME2012', 'AME2012all', 'DUZU', 'FRDM95', 'KTUY05', 'ETFSI12', 'HFB14']
 
     def load(self, name):
         "Imports a mass table from a file"
@@ -222,4 +222,6 @@ class Table(object):
 
 if __name__ == '__main__':
     print Table('AME2003').head().join(Table('AME2012').head(), Table('DUZU').odd_odd.head())
+    print Table('AME2012all').tail()
+    print Table('AME2012').tail()
     print Table.from_list([1,1])
